@@ -13,19 +13,28 @@
 
 #include "ViewStep.h"
 #include "modulesystem/InstanceKey.h"
+#include "widgets/LogWidget.h"
 
 #include <QStringList>
 
 class QLabel;
 class QObject;
 class QProgressBar;
+class QTabWidget;
 
 namespace Calamares
 {
 
 class Slideshow;
 
-class ExecutionViewStep : public ViewStep
+/**
+ * @class
+ *
+ * This is the implementation of the special ViewStep "Install"
+ * which takes care of an *exec* phase in the sequence. It runs
+ * jobs, shows the slideshow, etc.
+ */
+class UIDLLEXPORT ExecutionViewStep : public ViewStep
 {
     Q_OBJECT
 public:
@@ -56,10 +65,14 @@ private:
     QProgressBar* m_progressBar;
     QLabel* m_label;
     Slideshow* m_slideshow;
+    QTabWidget* m_tab_widget;
+    LogWidget* m_log_widget;
 
     QList< ModuleSystem::InstanceKey > m_jobInstanceKeys;
 
     void updateFromJobQueue( qreal percent, const QString& message );
+
+    void toggleLog();
 };
 
 }  // namespace Calamares
